

SSARecord
======================

.. currentmodule:: pyvo.dal.ssa

.. autoclass:: SSARecord
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SSARecord.acref
      ~SSARecord.dateobs
      ~SSARecord.dec
      ~SSARecord.format
      ~SSARecord.instr
      ~SSARecord.ra
      ~SSARecord.title

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SSARecord.getdataurl
      ~SSARecord.suggest_dataset_basename
      ~SSARecord.suggest_extension

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: acref
   .. autoattribute:: dateobs
   .. autoattribute:: dec
   .. autoattribute:: format
   .. autoattribute:: instr
   .. autoattribute:: ra
   .. autoattribute:: title

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: getdataurl
   .. automethod:: suggest_dataset_basename
   .. automethod:: suggest_extension

   
   